pub struct ApiAddGroupRelays {
pub group_id: i64,
pub relay_ids: Vec<i64>,
}Expand description
Group commands
Commands to manage and moderate groups. These commands can be used with business chats as well - they are groups. E.g., a common scenario would be to add human agents to business chat with the customer who connected via business address.
Add relays to group.
Network usage: interactive.
Syntax:
/_add relays #<groupId> <relayIds[0]>[,<relayIds[1]>...]Fields
group_id: i64relay_ids: Vec<i64>Trait Implementations
Sourceimpl Clone for ApiAddGroupRelays
impl Clone for ApiAddGroupRelays
Sourcefn clone(&self) -> ApiAddGroupRelays
fn clone(&self) -> ApiAddGroupRelays
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CommandSyntax for ApiAddGroupRelays
impl CommandSyntax for ApiAddGroupRelays
const COMMAND_BUF_SIZE: usize = 256
fn append_command_syntax(&self, buf: &mut String)
Sourcefn to_command_string(&self) -> String
fn to_command_string(&self) -> String
Generate a SimpleX command string from self
Sourceimpl Debug for ApiAddGroupRelays
impl Debug for ApiAddGroupRelays
Sourceimpl PartialEq for ApiAddGroupRelays
impl PartialEq for ApiAddGroupRelays
Sourcefn eq(&self, other: &ApiAddGroupRelays) -> bool
fn eq(&self, other: &ApiAddGroupRelays) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ApiAddGroupRelays