pub struct ApiBlockMembersForAll {
pub group_id: i64,
pub group_member_ids: Vec<i64>,
pub blocked: bool,
}Expand description
Group commands
Commands to manage and moderate groups. These commands can be used with business chats as well - they are groups. E.g., a common scenario would be to add human agents to business chat with the customer who connected via business address.
Block members. Requires Moderator role.
Network usage: background.
Syntax:
/_block #<groupId> <groupMemberIds[0]>[,<groupMemberIds[1]>...] blocked=on|offFields
group_id: i64group_member_ids: Vec<i64>blocked: boolTrait Implementations
Sourceimpl Clone for ApiBlockMembersForAll
impl Clone for ApiBlockMembersForAll
Sourcefn clone(&self) -> ApiBlockMembersForAll
fn clone(&self) -> ApiBlockMembersForAll
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CommandSyntax for ApiBlockMembersForAll
impl CommandSyntax for ApiBlockMembersForAll
const COMMAND_BUF_SIZE: usize = 256
fn append_command_syntax(&self, buf: &mut String)
Sourcefn to_command_string(&self) -> String
fn to_command_string(&self) -> String
Generate a SimpleX command string from self
Sourceimpl Debug for ApiBlockMembersForAll
impl Debug for ApiBlockMembersForAll
Sourceimpl PartialEq for ApiBlockMembersForAll
impl PartialEq for ApiBlockMembersForAll
impl StructuralPartialEq for ApiBlockMembersForAll