pub struct GroupLinkDataUpdated {
pub user: User,
pub group_info: GroupInfo,
pub group_link: GroupLink,
pub group_relays: Vec<GroupRelay>,
pub relays_changed: bool,
pub undocumented: JsonObject,
}Expand description
Group events
Bots may use these events to manage users’ groups and business address groups.
Please note: programming groups is more complex than programming direct connections
Group link data updated.
Fields
user: Usergroup_info: GroupInfogroup_link: GroupLinkgroup_relays: Vec<GroupRelay>relays_changed: boolundocumented: JsonObjectTrait Implementations
Sourceimpl Clone for GroupLinkDataUpdated
impl Clone for GroupLinkDataUpdated
Sourcefn clone(&self) -> GroupLinkDataUpdated
fn clone(&self) -> GroupLinkDataUpdated
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GroupLinkDataUpdated
impl Debug for GroupLinkDataUpdated
Sourceimpl<'de> Deserialize<'de> for GroupLinkDataUpdated
impl<'de> Deserialize<'de> for GroupLinkDataUpdated
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl EventData for GroupLinkDataUpdated
impl EventData for GroupLinkDataUpdated
Sourceimpl PartialEq for GroupLinkDataUpdated
impl PartialEq for GroupLinkDataUpdated
Sourcefn eq(&self, other: &GroupLinkDataUpdated) -> bool
fn eq(&self, other: &GroupLinkDataUpdated) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for GroupLinkDataUpdated
impl Serialize for GroupLinkDataUpdated
impl StructuralPartialEq for GroupLinkDataUpdated